@@ -332,17 +332,15 @@ def interpolate_timeseries(data, method='linear', multivariate=False):
                 continue
 
             nonnan = ~isnan
-            f = interp1d(_x[nonnan], col[nonnan], kind=method,
+            xnn, colnn = _x[nonnan], col[nonnan]
+            f = interp1d(xnn, colnn, kind=method,
                          copy=False, assume_sorted=True, bounds_error=False)
+            if method == "interpolate":
+                f.fill_value = "extrapolate"
+            else:
+                f.fill_value = (colnn[np.argmin(xnn)], colnn[np.argmax(xnn)])
             A[isnan, i] = f(_x[isnan])
 
-            # nearest-interpolate any nans at vals start and end
-            # TODO: replace nearest with linear/OLS?
-            valid = (~np.isnan(col)).nonzero()[0]
-            first, last = valid[0], valid[-1]
-            col[:first] = col[first]
-            col[last:] = col[last]
-
     ts = Timeseries.from_numpy(Domain(attrs, cvars, metas), X, Y, M)
     return ts
 
@@ -462,13 +460,15 @@ def granger_causality(data, max_lag=10, alpha=.05, *, callback=None):
     # http://statsmodels.sourceforge.net/devel/vector_ar.html#granger-causality
 
     data = data.interp()
-    domain = [var for var in data.domain.variables if var.is_continuous]
+    domain = [var for var in data.domain.variables
+              if var.is_continuous and var is not data.time_variable]
     res = []
 
     step = 0
+    nsteps = len(domain) * (len(domain) - 1)
     for row_attr in domain:
         for col_attr in domain:
-            if row_attr == col_attr or data.time_variable in (row_attr, col_attr):
+            if row_attr is col_attr:
                 continue
             X = Table.from_table(Domain([], [], [col_attr, row_attr], data.domain), data).metas
             try:
@@ -488,7 +488,7 @@ def granger_causality(data, max_lag=10, alpha=.05, *, callback=None):
 
             step += 1
             if callback:
-                callback(step / ((len(domain) - 1) ** 2 - len(domain) + 1))
+                callback(step / nsteps)
     return res
 
 
